@@ -203,6 +203,10 @@ class CloudClient(object):
                 profile['profile'] = name
                 self.opts['profiles'].update({name: profile})
                 self.opts['providers'][provider][driver]['profiles'].update({name: profile})
+            for name, map_dct in six.iteritems(pillars.pop('maps', {})):
+                if 'maps' not in self.opts:
+                    self.opts['maps'] = {}
+                self.opts['maps'][name] = map_dct
             self.opts.update(pillars)
 
     def _opts_defaults(self, **kwargs):
@@ -356,7 +360,7 @@ class CloudClient(object):
 
     def map_run(self, path=None, **kwargs):
         '''
-        Pass in a location for a map to execute
+        To execute a map
         '''
         kwarg = {}
         if path:
@@ -621,11 +625,7 @@ class Cloud(object):
             for driver, details in six.iteritems(drivers):
                 fun = '{0}.{1}'.format(driver, query)
                 if fun not in self.clouds:
-                    log.error(
-                        'Public cloud provider {0} is not available'.format(
-                            driver
-                        )
-                    )
+                    log.error('Public cloud provider %s is not available', driver)
                     continue
                 if alias not in pmap:
                     pmap[alias] = {}
@@ -638,10 +638,8 @@ class Cloud(object):
                         pmap[alias][driver] = self.clouds[fun]()
                 except Exception as err:
                     log.debug(
-                        'Failed to execute \'{0}()\' while querying for '
-                        'running nodes: {1}'.format(fun, err),
-                        # Show the traceback if the debug logging level is
-                        # enabled
+                        'Failed to execute \'%s()\' while querying for '
+                        'running nodes: %s', fun, err,
                         exc_info_on_loglevel=logging.DEBUG
                     )
                     # Failed to communicate with the provider, don't list any
@@ -677,11 +675,7 @@ class Cloud(object):
 
                 fun = '{0}.{1}'.format(driver, this_query)
                 if fun not in self.clouds:
-                    log.error(
-                        'Public cloud provider {0} is not available'.format(
-                            driver
-                        )
-                    )
+                    log.error('Public cloud provider %s is not available', driver)
                     continue
 
                 multiprocessing_data.append({
@@ -775,11 +769,7 @@ class Cloud(object):
         for driver, providers_data in six.iteritems(provider_by_driver):
             fun = '{0}.optimize_providers'.format(driver)
             if fun not in self.clouds:
-                log.debug(
-                    'The \'{0}\' cloud driver is unable to be optimized.'.format(
-                        driver
-                    )
-                )
+                log.debug('The \'%s\' cloud driver is unable to be optimized.', driver)
 
                 for name, prov_data in six.iteritems(providers_data):
                     if name not in new_providers:
@@ -812,10 +802,9 @@ class Cloud(object):
                 # The capability to gather locations is not supported by this
                 # cloud module
                 log.debug(
-                    'The \'{0}\' cloud driver defined under \'{1}\' provider '
-                    'alias is unable to get the locations information'.format(
-                        driver, alias
-                    )
+                    'The \'%s\' cloud driver defined under \'%s\' provider '
+                    'alias is unable to get the locations information',
+                    driver, alias
                 )
                 continue
 
@@ -831,11 +820,8 @@ class Cloud(object):
                     data[alias][driver] = self.clouds[fun]()
             except Exception as err:
                 log.error(
-                    'Failed to get the output of \'{0}()\': {1}'.format(
-                        fun, err
-                    ),
-                    # Show the traceback if the debug logging level is enabled
-                    exc_info_on_loglevel=logging.DEBUG
+                    'Failed to get the output of \'%s()\': %s',
+                    fun, err, exc_info_on_loglevel=logging.DEBUG
                 )
         return data
 
@@ -855,11 +841,9 @@ class Cloud(object):
                 # The capability to gather images is not supported by this
                 # cloud module
                 log.debug(
-                    'The \'{0}\' cloud driver defined under \'{1}\' provider '
-                    'alias is unable to get the images information'.format(
-                        driver,
-                        alias
-                    )
+                    'The \'%s\' cloud driver defined under \'%s\' provider '
+                    'alias is unable to get the images information',
+                    driver, alias
                 )
                 continue
 
@@ -874,11 +858,8 @@ class Cloud(object):
                     data[alias][driver] = self.clouds[fun]()
             except Exception as err:
                 log.error(
-                    'Failed to get the output of \'{0}()\': {1}'.format(
-                        fun, err
-                    ),
-                    # Show the traceback if the debug logging level is enabled
-                    exc_info_on_loglevel=logging.DEBUG
+                    'Failed to get the output of \'%s()\': %s',
+                    fun, err, exc_info_on_loglevel=logging.DEBUG
                 )
         return data
 
@@ -898,11 +879,9 @@ class Cloud(object):
                 # The capability to gather sizes is not supported by this
                 # cloud module
                 log.debug(
-                    'The \'{0}\' cloud driver defined under \'{1}\' provider '
-                    'alias is unable to get the sizes information'.format(
-                        driver,
-                        alias
-                    )
+                    'The \'%s\' cloud driver defined under \'%s\' provider '
+                    'alias is unable to get the sizes information',
+                    driver, alias
                 )
                 continue
 
@@ -917,11 +896,8 @@ class Cloud(object):
                     data[alias][driver] = self.clouds[fun]()
             except Exception as err:
                 log.error(
-                    'Failed to get the output of \'{0}()\': {1}'.format(
-                        fun, err
-                    ),
-                    # Show the traceback if the debug logging level is enabled
-                    exc_info_on_loglevel=logging.DEBUG
+                    'Failed to get the output of \'%s()\': %s',
+                    fun, err, exc_info_on_loglevel=logging.DEBUG
                 )
         return data
 
@@ -994,7 +970,7 @@ class Cloud(object):
                             })
 
         # destroying in parallel
-        if self.opts['parallel'] and len(parallel_data) > 0:
+        if self.opts['parallel'] and parallel_data:
             # set the pool size based on configuration or default to
             # the number of machines we're destroying
             if 'pool_size' in self.opts:
@@ -1002,7 +978,7 @@ class Cloud(object):
             else:
                 pool_size = len(parallel_data)
             log.info('Destroying in parallel mode; '
-                     'Cloud pool size: {0}'.format(pool_size))
+                     'Cloud pool size: %s', pool_size)
 
             # kick off the parallel destroy
             output_multip = enter_mainloop(
@@ -1188,11 +1164,9 @@ class Cloud(object):
         fun = '{0}.create'.format(driver)
         if fun not in self.clouds:
             log.error(
-                'Creating \'{0[name]}\' using \'{0[provider]}\' as the provider '
-                'cannot complete since \'{1}\' is not available'.format(
-                    vm_,
-                    driver
-                )
+                'Creating \'%s\' using \'%s\' as the provider '
+                'cannot complete since \'%s\' is not available',
+                vm_['name'], vm_['provider'], driver
             )
             return
 
@@ -1206,13 +1180,12 @@ class Cloud(object):
         if deploy:
             if not make_master and 'master' not in minion_dict:
                 log.warning(
-                    'There\'s no master defined on the \'{0}\' VM settings.'.format(
-                        vm_['name']
-                    )
+                    'There\'s no master defined on the \'%s\' VM settings.',
+                    vm_['name']
                 )
 
             if 'pub_key' not in vm_ and 'priv_key' not in vm_:
-                log.debug('Generating minion keys for \'{0[name]}\''.format(vm_))
+                log.debug('Generating minion keys for \'%s\'', vm_['name'])
                 priv, pub = salt.utils.cloud.gen_keys(
                     salt.config.get_cloud_config_value(
                         'keysize',
@@ -1238,11 +1211,7 @@ class Cloud(object):
             key_id = '.'.join([key_id, minion_dict['append_domain']])
 
         if make_master is True and 'master_pub' not in vm_ and 'master_pem' not in vm_:
-            log.debug(
-                'Generating the master keys for \'{0[name]}\''.format(
-                    vm_
-                )
-            )
+            log.debug('Generating the master keys for \'%s\'', vm_['name'])
             master_priv, master_pub = salt.utils.cloud.gen_keys(
                 salt.config.get_cloud_config_value(
                     'keysize',
@@ -1294,16 +1263,16 @@ class Cloud(object):
                 start = int(time.time())
                 while int(time.time()) < start + 60:
                     # We'll try every <timeout> seconds, up to a minute
-                    mopts_ = salt.config.DEFAULT_MINION_OPTS
+                    mopts_ = salt.config.DEFAULT_MASTER_OPTS
                     conf_path = '/'.join(self.opts['conf_file'].split('/')[:-1])
                     mopts_.update(
-                        salt.config.minion_config(
+                        salt.config.master_config(
                             os.path.join(conf_path,
-                                         'minion')
+                                         'master')
                         )
                     )
 
-                    client = salt.client.get_local_client(mopts=self.opts)
+                    client = salt.client.get_local_client(mopts=mopts_)
 
                     ret = client.cmd(
                         vm_['name'],
@@ -1318,10 +1287,8 @@ class Cloud(object):
                         break
         except KeyError as exc:
             log.exception(
-                'Failed to create VM {0}. Configuration value {1} needs '
-                'to be set'.format(
-                    vm_['name'], exc
-                )
+                'Failed to create VM %s. Configuration value %s needs '
+                'to be set', vm_['name'], exc
             )
         # If it's a map then we need to respect the 'requires'
         # so we do it later
@@ -1330,11 +1297,7 @@ class Cloud(object):
         except KeyError:
             opt_map = False
         if self.opts['parallel'] and self.opts['start_action'] and not opt_map:
-            log.info(
-                'Running {0} on {1}'.format(
-                    self.opts['start_action'], vm_['name']
-                )
-            )
+            log.info('Running %s on %s', self.opts['start_action'], vm_['name'])
             client = salt.client.get_local_client(mopts=self.opts)
             action_out = client.cmd(
                 vm_['name'],
@@ -1372,11 +1335,9 @@ class Cloud(object):
         fun = '{0}.{1}'.format(driver, extra_['action'])
         if fun not in self.clouds:
             log.error(
-                'Creating \'{0[name]}\' using \'{0[provider]}\' as the provider '
-                'cannot complete since \'{1}\' is not available'.format(
-                    extra_,
-                    driver
-                )
+                'Creating \'%s\' using \'%s\' as the provider '
+                'cannot complete since \'%s\' is not available',
+                extra_['name'], extra_['provider'], driver
             )
             return
 
@@ -1388,11 +1349,9 @@ class Cloud(object):
                 output = self.clouds[fun](**extra_)
         except KeyError as exc:
             log.exception(
-                (
-                    'Failed to perform {0[provider]}.{0[action]} '
-                    'on {0[name]}. '
-                    'Configuration value {1} needs to be set'
-                ).format(extra_, exc)
+                'Failed to perform %s.%s on %s. '
+                'Configuration value %s needs to be set',
+                extra_['provider'], extra_['action'], extra_['name'], exc
             )
         return output
 
@@ -1441,7 +1400,7 @@ class Cloud(object):
             if name in vms:
                 prov = vms[name]['provider']
                 driv = vms[name]['driver']
-                msg = u'{0} already exists under {1}:{2}'.format(
+                msg = '{0} already exists under {1}:{2}'.format(
                     name, prov, driv
                 )
                 log.error(msg)
@@ -1502,11 +1461,7 @@ class Cloud(object):
                 valid_function = True
                 fun = '{0}.{1}'.format(driver, self.opts['action'])
                 if fun not in self.clouds:
-                    log.info(
-                        '\'{0}()\' is not available. Not actioning...'.format(
-                            fun
-                        )
-                    )
+                    log.info('\'%s()\' is not available. Not actioning...', fun)
                     valid_function = False
                 for vm_name, vm_details in six.iteritems(vms):
                     if not names:
@@ -1609,9 +1564,8 @@ class Cloud(object):
             )
 
         log.debug(
-            'Trying to execute \'{0}\' with the following kwargs: {1}'.format(
-                fun, kwargs
-            )
+            'Trying to execute \'%s\' with the following kwargs: %s',
+            fun, kwargs
         )
 
         with salt.utils.context.func_globals_inject(
@@ -1642,16 +1596,15 @@ class Cloud(object):
                 if fun not in self.clouds:
                     # Mis-configured provider that got removed?
                     log.warning(
-                        'The cloud driver, \'{0}\', configured under the '
-                        '\'{1}\' cloud provider alias, could not be loaded. '
+                        'The cloud driver, \'%s\', configured under the '
+                        '\'%s\' cloud provider alias, could not be loaded. '
                         'Please check your provider configuration files and '
                         'ensure all required dependencies are installed '
-                        'for the \'{0}\' driver.\n'
-                        'In rare cases, this could indicate the \'{2}()\' '
-                        'function could not be found.\nRemoving \'{0}\' from '
-                        'the available providers list'.format(
-                            driver, alias, fun
-                        )
+                        'for the \'%s\' driver.\n'
+                        'In rare cases, this could indicate the \'%s()\' '
+                        'function could not be found.\nRemoving \'%s\' from '
+                        'the available providers list',
+                        driver, alias, driver, fun, driver
                     )
                     self.opts['providers'][alias].pop(driver)
 
@@ -1668,10 +1621,10 @@ class Cloud(object):
                 ):
                     if self.clouds[fun]() is False:
                         log.warning(
-                            'The cloud driver, \'{0}\', configured under the '
-                            '\'{1}\' cloud provider alias is not properly '
+                            'The cloud driver, \'%s\', configured under the '
+                            '\'%s\' cloud provider alias is not properly '
                             'configured. Removing it from the available '
-                            'providers list.'.format(driver, alias)
+                            'providers list.', driver, alias
                         )
                         self.opts['providers'][alias].pop(driver)
 
@@ -1769,8 +1722,9 @@ class Map(Cloud):
                         state_action = matching_states[action]
                     except KeyError:
                         log.error(
-                            'The use of \'{0}\' as an action is not supported in this context. '
-                            'Only \'start\', \'stop\', and \'reboot\' are supported options.'.format(action)
+                            'The use of \'%s\' as an action is not supported '
+                            'in this context. Only \'start\', \'stop\', and '
+                            '\'reboot\' are supported options.', action
                         )
                         raise SaltCloudException()
                     if vm_details != 'Absent' and vm_details['state'].lower() in state_action:
@@ -1779,16 +1733,27 @@ class Map(Cloud):
 
     def read(self):
         '''
-        Read in the specified map file and return the map structure
+        Read in the specified map and return the map structure
         '''
         map_ = None
         if self.opts.get('map', None) is None:
             if self.opts.get('map_data', None) is None:
-                return {}
+                if self.opts.get('map_pillar', None) is None:
+                    pass
+                elif self.opts.get('map_pillar') not in self.opts.get('maps'):
+                    log.error(
+                        'The specified map not found in pillar at '
+                        '\'cloud:maps:%s\'', self.opts['map_pillar']
+                    )
+                    raise SaltCloudNotFound()
+                else:
+                    # 'map_pillar' is provided, try to use it
+                    map_ = self.opts['maps'][self.opts.get('map_pillar')]
             else:
+                # 'map_data' is provided, try to use it
                 map_ = self.opts['map_data']
-
-        if not map_:
+        else:
+            # 'map' is provided, try to use it
             local_minion_opts = copy.deepcopy(self.opts)
             local_minion_opts['file_client'] = 'local'
             self.minion = salt.minion.MasterMinion(local_minion_opts)
@@ -1796,8 +1761,8 @@ class Map(Cloud):
             if not os.path.isfile(self.opts['map']):
                 if not (self.opts['map']).startswith('salt://'):
                     log.error(
-                        'The specified map file does not exist: \'{0}\''.format(
-                            self.opts['map'])
+                        'The specified map file does not exist: \'%s\'',
+                        self.opts['map']
                     )
                     raise SaltCloudNotFound()
             if (self.opts['map']).startswith('salt://'):
@@ -1805,7 +1770,7 @@ class Map(Cloud):
             else:
                 cached_map = self.opts['map']
             try:
-                renderer = self.opts.get('renderer', 'yaml_jinja')
+                renderer = self.opts.get('renderer', 'jinja|yaml')
                 rend = salt.loader.render(self.opts, {})
                 blacklist = self.opts.get('renderer_blacklist')
                 whitelist = self.opts.get('renderer_whitelist')
@@ -1814,17 +1779,19 @@ class Map(Cloud):
                 )
             except Exception as exc:
                 log.error(
-                    'Rendering map {0} failed, render error:\n{1}'.format(
-                        self.opts['map'], exc
-                    ),
+                    'Rendering map %s failed, render error:\n%s',
+                    self.opts['map'], exc,
                     exc_info_on_loglevel=logging.DEBUG
                 )
                 return {}
 
-        if 'include' in map_:
-            map_ = salt.config.include_config(
-                map_, self.opts['map'], verbose=False
-            )
+            if 'include' in map_:
+                map_ = salt.config.include_config(
+                    map_, self.opts['map'], verbose=False
+                )
+
+        if not map_:
+            return {}
 
         # Create expected data format if needed
         for profile, mapped in six.iteritems(map_.copy()):
@@ -1935,7 +1902,8 @@ class Map(Cloud):
         pmap = self.map_providers_parallel(cached=cached)
         exist = set()
         defined = set()
-        for profile_name, nodes in six.iteritems(copy.deepcopy(self.rendered_map)):
+        rendered_map = copy.deepcopy(self.rendered_map)
+        for profile_name, nodes in six.iteritems(rendered_map):
             if profile_name not in self.opts['profiles']:
                 msg = (
                     'The required profile, \'{0}\', defined in the map '
@@ -1953,34 +1921,35 @@ class Map(Cloud):
 
             profile_data = self.opts['profiles'].get(profile_name)
 
-            # Get associated provider data, in case something like size
-            # or image is specified in the provider file. See issue #32510.
-            alias, driver = profile_data.get('provider').split(':')
-            provider_details = copy.deepcopy(self.opts['providers'][alias][driver])
-            del provider_details['profiles']
-
-            # Update the provider details information with profile data
-            # Profile data should override provider data, if defined.
-            # This keeps map file data definitions consistent with -p usage.
-            salt.utils.dictupdate.update(provider_details, profile_data)
-            profile_data = provider_details
-
             for nodename, overrides in six.iteritems(nodes):
-                # Get the VM name
-                nodedata = copy.deepcopy(profile_data)
+                # Get associated provider data, in case something like size
+                # or image is specified in the provider file. See issue #32510.
+                if 'provider' in overrides and overrides['provider'] != profile_data['provider']:
+                    alias, driver = overrides.get('provider').split(':')
+                else:
+                    alias, driver = profile_data.get('provider').split(':')
+
+                provider_details = copy.deepcopy(self.opts['providers'][alias][driver])
+                del provider_details['profiles']
+
+                # Update the provider details information with profile data
+                # Profile data and node overrides should override provider data, if defined.
+                # This keeps map file data definitions consistent with -p usage.
+                salt.utils.dictupdate.update(provider_details, profile_data)
+                nodedata = copy.deepcopy(provider_details)
+
                 # Update profile data with the map overrides
                 for setting in ('grains', 'master', 'minion', 'volumes',
                                 'requires'):
                     deprecated = 'map_{0}'.format(setting)
                     if deprecated in overrides:
                         log.warning(
-                            'The use of \'{0}\' on the \'{1}\' mapping has '
+                            'The use of \'%s\' on the \'%s\' mapping has '
                             'been deprecated. The preferred way now is to '
-                            'just define \'{2}\'. For now, salt-cloud will do '
+                            'just define \'%s\'. For now, salt-cloud will do '
                             'the proper thing and convert the deprecated '
-                            'mapping into the preferred one.'.format(
-                                deprecated, nodename, setting
-                            )
+                            'mapping into the preferred one.',
+                            deprecated, nodename, setting
                         )
                         overrides[setting] = overrides.pop(deprecated)
 
@@ -1994,7 +1963,7 @@ class Map(Cloud):
                     )
                     del overrides['minion']['grains']
                     # remove minion key if now is empty dict
-                    if len(overrides['minion']) == 0:
+                    if not overrides['minion']:
                         del overrides['minion']
 
                 nodedata = salt.utils.dictupdate.update(nodedata, overrides)
@@ -2031,8 +2000,8 @@ class Map(Cloud):
                             # Machine already removed
                             break
 
-                        log.warning("'{0}' already exists, removing from "
-                                    'the create map.'.format(name))
+                        log.warning("'%s' already exists, removing from "
+                                    'the create map.', name)
 
                         if 'existing' not in ret:
                             ret['existing'] = {}
@@ -2061,10 +2030,10 @@ class Map(Cloud):
             raise SaltCloudException(msg)
         # Go through the create list and calc dependencies
         for key, val in six.iteritems(dmap['create']):
-            log.info('Calculating dependencies for {0}'.format(key))
+            log.info('Calculating dependencies for %s', key)
             level = 0
             level = self._calcdep(dmap, key, val, level)
-            log.debug('Got execution order {0} for {1}'.format(level, key))
+            log.debug('Got execution order %s for %s', level, key)
             dmap['create'][key]['level'] = level
 
         try:
@@ -2073,10 +2042,10 @@ class Map(Cloud):
             existing_list = six.iteritems({})
 
         for key, val in existing_list:
-            log.info('Calculating dependencies for {0}'.format(key))
+            log.info('Calculating dependencies for %s', key)
             level = 0
             level = self._calcdep(dmap, key, val, level)
-            log.debug('Got execution order {0} for {1}'.format(level, key))
+            log.debug('Got execution order %s for %s', level, key)
             dmap['existing'][key]['level'] = level
 
         # Now sort the create list based on dependencies
@@ -2094,7 +2063,7 @@ class Map(Cloud):
                 if profile.get('make_master', False) is True
             ))
             master_minion_name = master_name
-            log.debug('Creating new master \'{0}\''.format(master_name))
+            log.debug('Creating new master \'%s\'', master_name)
             if salt.config.get_cloud_config_value(
                 'deploy',
                 master_profile,
@@ -2106,9 +2075,7 @@ class Map(Cloud):
                 )
 
             # Generate the master keys
-            log.debug(
-                'Generating master keys for \'{0[name]}\''.format(master_profile)
-            )
+            log.debug('Generating master keys for \'%s\'', master_profile['name'])
             priv, pub = salt.utils.cloud.gen_keys(
                 salt.config.get_cloud_config_value(
                     'keysize',
@@ -2145,9 +2112,7 @@ class Map(Cloud):
                 if make_minion is False:
                     continue
 
-                log.debug(
-                    'Generating minion keys for \'{0[name]}\''.format(profile)
-                )
+                log.debug('Generating minion keys for \'%s\'', profile['name'])
                 priv, pub = salt.utils.cloud.gen_keys(
                     salt.config.get_cloud_config_value(
                         'keysize',
@@ -2261,23 +2226,20 @@ class Map(Cloud):
                     output[name].pop('deploy_kwargs', None)
             except SaltCloudException as exc:
                 log.error(
-                    'Failed to deploy \'{0}\'. Error: {1}'.format(
-                        name, exc
-                    ),
-                    # Show the traceback if the debug logging level is enabled
-                    exc_info_on_loglevel=logging.DEBUG
+                    'Failed to deploy \'%s\'. Error: %s',
+                    name, exc, exc_info_on_loglevel=logging.DEBUG
                 )
                 output[name] = {'Error': str(exc)}
 
         for name in dmap.get('destroy', ()):
             output[name] = self.destroy(name)
 
-        if self.opts['parallel'] and len(parallel_data) > 0:
+        if self.opts['parallel'] and parallel_data:
             if 'pool_size' in self.opts:
                 pool_size = self.opts['pool_size']
             else:
                 pool_size = len(parallel_data)
-            log.info('Cloud pool size: {0}'.format(pool_size))
+            log.info('Cloud pool size: %s', pool_size)
             output_multip = enter_mainloop(
                 _create_multiprocessing, parallel_data, pool_size=pool_size)
             # We have deployed in parallel, now do start action in
@@ -2293,11 +2255,7 @@ class Map(Cloud):
 
                 out = {}
                 for group in actionlist:
-                    log.info(
-                        'Running {0} on {1}'.format(
-                            self.opts['start_action'], ', '.join(group)
-                        )
-                    )
+                    log.info('Running %s on %s', self.opts['start_action'], ', '.join(group))
                     client = salt.client.get_local_client()
                     out.update(client.cmd(
                         ','.join(group), self.opts['start_action'],
@@ -2337,11 +2295,8 @@ def create_multiprocessing(parallel_data, queue=None):
         )
     except SaltCloudException as exc:
         log.error(
-            'Failed to deploy \'{0[name]}\'. Error: {1}'.format(
-                parallel_data, exc
-            ),
-            # Show the traceback if the debug logging level is enabled
-            exc_info_on_loglevel=logging.DEBUG
+            'Failed to deploy \'%s\'. Error: %s',
+            parallel_data['name'], exc, exc_info_on_loglevel=logging.DEBUG
         )
         return {parallel_data['name']: {'Error': str(exc)}}
 
@@ -2376,11 +2331,8 @@ def destroy_multiprocessing(parallel_data, queue=None):
 
     except SaltCloudException as exc:
         log.error(
-            'Failed to destroy {0}. Error: {1}'.format(
-                parallel_data['name'], exc
-            ),
-            # Show the traceback if the debug logging level is enabled
-            exc_info_on_loglevel=logging.DEBUG
+            'Failed to destroy %s. Error: %s',
+            parallel_data['name'], exc, exc_info_on_loglevel=logging.DEBUG
         )
         return {parallel_data['name']: {'Error': str(exc)}}
 
@@ -2414,11 +2366,8 @@ def run_parallel_map_providers_query(data, queue=None):
             )
     except Exception as err:
         log.debug(
-            'Failed to execute \'{0}()\' while querying for running '
-            'nodes: {1}'.format(data['fun'], err),
-            # Show the traceback if the debug logging level is
-            # enabled
-            exc_info_on_loglevel=logging.DEBUG
+            'Failed to execute \'%s()\' while querying for running nodes: %s',
+            data['fun'], err, exc_info_on_loglevel=logging.DEBUG
         )
         # Failed to communicate with the provider, don't list any nodes
         return data['alias'], data['driver'], ()
