@@ -69,9 +69,10 @@ HAS_WINDOWS_MODULES = False
 try:
     if salt.utils.platform.is_windows():
         import win32api
-        import win32file
         import win32con
-        from pywintypes import error as pywinerror
+        import win32file
+        import win32security
+        import salt.platform.win
         HAS_WINDOWS_MODULES = True
 except ImportError:
     HAS_WINDOWS_MODULES = False
@@ -853,7 +854,7 @@ def stats(path, hash_type='sha256', follow_symlinks=True):
     ret['mtime'] = pstat.st_mtime
     ret['ctime'] = pstat.st_ctime
     ret['size'] = pstat.st_size
-    ret['mode'] = six.text_type(oct(stat.S_IMODE(pstat.st_mode)))
+    ret['mode'] = salt.utils.files.normalize_mode(oct(stat.S_IMODE(pstat.st_mode)))
     if hash_type:
         ret['sum'] = get_sum(path, hash_type)
     ret['type'] = 'file'
@@ -1071,7 +1072,7 @@ def remove(path, force=False):
         raise SaltInvocationError('File path must be absolute: {0}'.format(path))
 
     # Does the file/folder exists
-    if not os.path.exists(path):
+    if not os.path.exists(path) and not is_link(path):
         raise CommandExecutionError('Path not found: {0}'.format(path))
 
     # Remove ReadOnly Attribute
@@ -1147,10 +1148,19 @@ def symlink(src, link):
 
     is_dir = os.path.isdir(src)
 
+    # Elevate the token from the current process
+    desired_access = (
+        win32security.TOKEN_QUERY |
+        win32security.TOKEN_ADJUST_PRIVILEGES
+    )
+    th = win32security.OpenProcessToken(win32api.GetCurrentProcess(),
+                                        desired_access)
+    salt.platform.win.elevate_token(th)
+
     try:
         win32file.CreateSymbolicLink(link, src, int(is_dir))
         return True
-    except pywinerror as exc:
+    except win32file.error as exc:
         raise CommandExecutionError(
             'Could not create \'{0}\' - [{1}] {2}'.format(
                 link,
@@ -1584,7 +1594,8 @@ def check_perms(path,
                 reset=False):
     '''
     Check owner and permissions for the passed directory. This function checks
-    the permissions and sets them, returning the changes made.
+    the permissions and sets them, returning the changes made. Used by the file
+    state to populate the return dict
 
     Args:
 
@@ -1609,11 +1620,11 @@ def check_perms(path,
 
         inheritance (bool):
             ``True will check if inheritance is enabled and enable it. ``False``
-            will check if inheritance is disabled and disable it. Defaultl is
+            will check if inheritance is disabled and disable it. Default is
             ``True``.
 
         reset (bool):
-            ``True`` will show what permisisons will be removed by resetting the
+            ``True`` will show what permissions will be removed by resetting the
             DACL. ``False`` will do nothing. Default is ``False``.
 
     Returns:
@@ -1637,356 +1648,14 @@ def check_perms(path,
 
     path = os.path.expanduser(path)
 
-    if not ret:
-        ret = {'name': path,
-               'changes': {},
-               'pchanges': {},
-               'comment': [],
-               'result': True}
-        orig_comment = ''
-    else:
-        orig_comment = ret['comment']
-        ret['comment'] = []
-
-    # Check owner
-    if owner:
-        owner = salt.utils.win_dacl.get_name(principal=owner)
-        current_owner = salt.utils.win_dacl.get_owner(obj_name=path)
-        if owner != current_owner:
-            if __opts__['test'] is True:
-                ret['pchanges']['owner'] = owner
-            else:
-                try:
-                    salt.utils.win_dacl.set_owner(
-                        obj_name=path,
-                        principal=owner)
-                    ret['changes']['owner'] = owner
-                except CommandExecutionError:
-                    ret['result'] = False
-                    ret['comment'].append(
-                        'Failed to change owner to "{0}"'.format(owner))
-
-    # Check permissions
-    cur_perms = salt.utils.win_dacl.get_permissions(obj_name=path)
-
-    # Verify Deny Permissions
-    changes = {}
-    if deny_perms is not None:
-        for user in deny_perms:
-            # Check that user exists:
-            try:
-                user_name = salt.utils.win_dacl.get_name(principal=user)
-            except CommandExecutionError:
-                ret['comment'].append(
-                    'Deny Perms: User "{0}" missing from Target System'.format(user))
-                continue
-
-            # Get the proper applies_to text
-            if 'applies_to' in deny_perms[user]:
-                applies_to = deny_perms[user]['applies_to']
-                at_flag = salt.utils.win_dacl.flags().ace_prop['file'][applies_to]
-                applies_to_text = salt.utils.win_dacl.flags().ace_prop['file'][at_flag]
-
-            else:
-                applies_to = None
-
-            if user_name not in cur_perms:
-                changes[user] = {'perms': deny_perms[user]['perms']}
-                if applies_to:
-                    changes[user]['applies_to'] = applies_to
-
-            else:
-
-                # Check Perms
-                if isinstance(deny_perms[user]['perms'], six.string_types):
-                    if not salt.utils.win_dacl.has_permission(
-                            obj_name=path,
-                            principal=user_name,
-                            permission=deny_perms[user]['perms'],
-                            access_mode='deny',
-                            exact=False):
-                        changes[user] = {'perms': deny_perms[user]['perms']}
-                else:
-                    for perm in deny_perms[user]['perms']:
-                        if not salt.utils.win_dacl.has_permission(
-                                obj_name=path,
-                                principal=user_name,
-                                permission=perm,
-                                access_mode='deny',
-                                exact=False):
-                            if user not in changes:
-                                changes[user] = {'perms': []}
-                            changes[user]['perms'].append(deny_perms[user]['perms'])
-
-                # Check if applies_to was passed
-                if applies_to:
-                    # Is there a deny permission set
-                    if 'deny' in cur_perms[user_name]:
-                        # If the applies to settings are different, use the new one
-                        if not cur_perms[user_name]['deny']['applies to'] == applies_to_text:
-                            if user not in changes:
-                                changes[user] = {}
-                            changes[user]['applies_to'] = applies_to
-
-    if changes:
-        ret['pchanges']['deny_perms'] = {}
-        ret['changes']['deny_perms'] = {}
-        for user in changes:
-            user_name = salt.utils.win_dacl.get_name(principal=user)
-
-            if __opts__['test'] is True:
-                ret['pchanges']['deny_perms'][user] = changes[user]
-            else:
-                # Get applies_to
-                applies_to = None
-                if 'applies_to' not in changes[user]:
-                    # Get current "applies to" settings from the file
-                    if user_name in cur_perms and 'deny' in cur_perms[user_name]:
-                        for flag in salt.utils.win_dacl.flags().ace_prop['file']:
-                            if salt.utils.win_dacl.flags().ace_prop['file'][flag] == \
-                                    cur_perms[user_name]['deny']['applies to']:
-                                at_flag = flag
-                                for flag1 in salt.utils.win_dacl.flags().ace_prop['file']:
-                                    if salt.utils.win_dacl.flags().ace_prop['file'][flag1] == at_flag:
-                                        applies_to = flag1
-                    if not applies_to:
-                        applies_to = 'this_folder_subfolders_files'
-                else:
-                    applies_to = changes[user]['applies_to']
-
-                perms = []
-                if 'perms' not in changes[user]:
-                    # Get current perms
-                    # Check for basic perms
-                    for perm in cur_perms[user_name]['deny']['permissions']:
-                        for flag in salt.utils.win_dacl.flags().ace_perms['file']['basic']:
-                            if salt.utils.win_dacl.flags().ace_perms['file']['basic'][flag] == perm:
-                                perm_flag = flag
-                                for flag1 in salt.utils.win_dacl.flags().ace_perms['file']['basic']:
-                                    if salt.utils.win_dacl.flags().ace_perms['file']['basic'][flag1] == perm_flag:
-                                        perms = flag1
-                    # Make a list of advanced perms
-                    if not perms:
-                        for perm in cur_perms[user_name]['deny']['permissions']:
-                            for flag in salt.utils.win_dacl.flags().ace_perms['file']['advanced']:
-                                if salt.utils.win_dacl.flags().ace_perms['file']['advanced'][flag] == perm:
-                                    perm_flag = flag
-                                    for flag1 in salt.utils.win_dacl.flags().ace_perms['file']['advanced']:
-                                        if salt.utils.win_dacl.flags().ace_perms['file']['advanced'][flag1] == perm_flag:
-                                            perms.append(flag1)
-                else:
-                    perms = changes[user]['perms']
-
-                try:
-                    salt.utils.win_dacl.set_permissions(
-                        obj_name=path,
-                        principal=user_name,
-                        permissions=perms,
-                        access_mode='deny',
-                        applies_to=applies_to)
-                    ret['changes']['deny_perms'][user] = changes[user]
-                except CommandExecutionError:
-                    ret['result'] = False
-                    ret['comment'].append(
-                        'Failed to deny permissions for "{0}" to '
-                        '{1}'.format(user, changes[user]))
-
-    # Verify Grant Permissions
-    changes = {}
-    if grant_perms is not None:
-        for user in grant_perms:
-            # Check that user exists:
-            try:
-                user_name = salt.utils.win_dacl.get_name(principal=user)
-            except CommandExecutionError:
-                ret['comment'].append(
-                    'Grant Perms: User "{0}" missing from Target System'.format(user))
-                continue
-
-            # Get the proper applies_to text
-            if 'applies_to' in grant_perms[user]:
-                applies_to = grant_perms[user]['applies_to']
-                at_flag = salt.utils.win_dacl.flags().ace_prop['file'][applies_to]
-                applies_to_text = salt.utils.win_dacl.flags().ace_prop['file'][at_flag]
-
-            else:
-                applies_to = None
-
-            if user_name not in cur_perms:
-
-                changes[user] = {'perms': grant_perms[user]['perms']}
-                if applies_to:
-                    changes[user]['applies_to'] = applies_to
-
-            else:
-
-                # Check Perms
-                if isinstance(grant_perms[user]['perms'], six.string_types):
-                    if not salt.utils.win_dacl.has_permission(
-                            obj_name=path,
-                            principal=user_name,
-                            permission=grant_perms[user]['perms'],
-                            access_mode='grant'):
-                        changes[user] = {'perms': grant_perms[user]['perms']}
-                else:
-                    for perm in grant_perms[user]['perms']:
-                        if not salt.utils.win_dacl.has_permission(
-                                obj_name=path,
-                                principal=user_name,
-                                permission=perm,
-                                access_mode='grant',
-                                exact=False):
-                            if user not in changes:
-                                changes[user] = {'perms': []}
-                            changes[user]['perms'].append(grant_perms[user]['perms'])
-
-                # Check if applies_to was passed
-                if applies_to:
-                    # Is there a deny permission set
-                    if 'grant' in cur_perms[user_name]:
-                        # If the applies to settings are different, use the new one
-                        if not cur_perms[user_name]['grant']['applies to'] == applies_to_text:
-                            if user not in changes:
-                                changes[user] = {}
-                            changes[user]['applies_to'] = applies_to
-
-    if changes:
-        ret['pchanges']['grant_perms'] = {}
-        ret['changes']['grant_perms'] = {}
-        for user in changes:
-            user_name = salt.utils.win_dacl.get_name(principal=user)
-            if __opts__['test'] is True:
-                ret['pchanges']['grant_perms'][user] = changes[user]
-            else:
-                applies_to = None
-                if 'applies_to' not in changes[user]:
-                    # Get current "applies_to" settings from the file
-                    if user_name in cur_perms and 'grant' in cur_perms[user_name]:
-                        for flag in salt.utils.win_dacl.flags().ace_prop['file']:
-                            if salt.utils.win_dacl.flags().ace_prop['file'][flag] == \
-                                    cur_perms[user_name]['grant']['applies to']:
-                                at_flag = flag
-                                for flag1 in salt.utils.win_dacl.flags().ace_prop['file']:
-                                    if salt.utils.win_dacl.flags().ace_prop['file'][flag1] == at_flag:
-                                        applies_to = flag1
-                    if not applies_to:
-                        applies_to = 'this_folder_subfolders_files'
-                else:
-                    applies_to = changes[user]['applies_to']
-
-                perms = []
-                if 'perms' not in changes[user]:
-                    # Check for basic perms
-                    for perm in cur_perms[user_name]['grant']['permissions']:
-                        for flag in salt.utils.win_dacl.flags().ace_perms['file']['basic']:
-                            if salt.utils.win_dacl.flags().ace_perms['file']['basic'][flag] == perm:
-                                perm_flag = flag
-                                for flag1 in salt.utils.win_dacl.flags().ace_perms['file']['basic']:
-                                    if salt.utils.win_dacl.flags().ace_perms['file']['basic'][flag1] == perm_flag:
-                                        perms = flag1
-                    # Make a list of advanced perms
-                    if not perms:
-                        for perm in cur_perms[user_name]['grant']['permissions']:
-                            for flag in salt.utils.win_dacl.flags().ace_perms['file']['advanced']:
-                                if salt.utils.win_dacl.flags().ace_perms['file']['advanced'][flag] == perm:
-                                    perm_flag = flag
-                                    for flag1 in salt.utils.win_dacl.flags().ace_perms['file']['advanced']:
-                                        if salt.utils.win_dacl.flags().ace_perms['file']['advanced'][flag1] == perm_flag:
-                                            perms.append(flag1)
-                else:
-                    perms = changes[user]['perms']
-
-                try:
-                    salt.utils.win_dacl.set_permissions(
-                        obj_name=path,
-                        principal=user_name,
-                        permissions=perms,
-                        access_mode='grant',
-                        applies_to=applies_to)
-                    ret['changes']['grant_perms'][user] = changes[user]
-                except CommandExecutionError:
-                    ret['result'] = False
-                    ret['comment'].append(
-                        'Failed to grant permissions for "{0}" to '
-                        '{1}'.format(user, changes[user]))
-
-    # Check inheritance
-    if inheritance is not None:
-        if not inheritance == salt.utils.win_dacl.get_inheritance(obj_name=path):
-            if __opts__['test'] is True:
-                ret['pchanges']['inheritance'] = inheritance
-            else:
-                try:
-                    salt.utils.win_dacl.set_inheritance(
-                        obj_name=path,
-                        enabled=inheritance)
-                    ret['changes']['inheritance'] = inheritance
-                except CommandExecutionError:
-                    ret['result'] = False
-                    ret['comment'].append(
-                        'Failed to set inheritance for "{0}" to '
-                        '{1}'.format(path, inheritance))
-
-    # Check reset
-    # If reset=True, which users will be removed as a result
-    if reset:
-        # Reload perms so you can reset them
-        cur_perms = salt.utils.win_dacl.get_permissions(obj_name=path)
-        for user_name in cur_perms:
-            if grant_perms is not None and \
-                    user_name.lower() not in dict(
-                        (k.lower(), v) for k, v in six.iteritems(grant_perms)):
-                if 'grant' in cur_perms[user_name] and \
-                        not cur_perms[user_name]['grant']['inherited']:
-                    if __opts__['test'] is True:
-                        if 'remove_perms' not in ret['pchanges']:
-                            ret['pchanges']['remove_perms'] = {}
-                        ret['pchanges']['remove_perms'].update(
-                            {user_name: cur_perms[user_name]})
-                    else:
-                        if 'remove_perms' not in ret['changes']:
-                            ret['changes']['remove_perms'] = {}
-                        salt.utils.win_dacl.rm_permissions(
-                            obj_name=path,
-                            principal=user_name,
-                            ace_type='grant')
-                        ret['changes']['remove_perms'].update(
-                            {user_name: cur_perms[user_name]})
-            if deny_perms is not None and \
-                    user_name.lower() not in dict(
-                        (k.lower(), v) for k, v in six.iteritems(deny_perms)):
-                if 'deny' in cur_perms[user_name] and \
-                        not cur_perms[user_name]['deny']['inherited']:
-                    if __opts__['test'] is True:
-                        if 'remove_perms' not in ret['pchanges']:
-                            ret['pchanges']['remove_perms'] = {}
-                        ret['pchanges']['remove_perms'].update(
-                            {user_name: cur_perms[user_name]})
-                    else:
-                        if 'remove_perms' not in ret['changes']:
-                            ret['changes']['remove_perms'] = {}
-                        salt.utils.win_dacl.rm_permissions(
-                            obj_name=path,
-                            principal=user_name,
-                            ace_type='deny')
-                        ret['changes']['remove_perms'].update(
-                            {user_name: cur_perms[user_name]})
-
-    # Re-add the Original Comment if defined
-    if isinstance(orig_comment, six.string_types):
-        if orig_comment:
-            ret['comment'].insert(0, orig_comment)
-    else:
-        if orig_comment:
-            ret['comment'] = orig_comment.extend(ret['comment'])
-
-    ret['comment'] = '\n'.join(ret['comment'])
-
-    # Set result for test = True
-    if __opts__['test'] and (ret['changes'] or ret['pchanges']):
-        ret['result'] = None
-
-    return ret
+    return __utils__['dacl.check_perms'](obj_name=path,
+                                         obj_type='file',
+                                         ret=ret,
+                                         owner=owner,
+                                         grant_perms=grant_perms,
+                                         deny_perms=deny_perms,
+                                         inheritance=inheritance,
+                                         reset=reset)
 
 
 def set_perms(path,
@@ -2067,98 +1736,9 @@ def set_perms(path,
         # Specify advanced attributes with a list
         salt '*' file.set_perms C:\\Temp\\ "{'jsnuffy': {'perms': ['read_attributes', 'read_ea'], 'applies_to': 'this_folder_only'}}"
     '''
-    ret = {}
-
-    if reset:
-        # Get an empty DACL
-        dacl = salt.utils.win_dacl.dacl()
-
-        # Get an empty perms dict
-        cur_perms = {}
-
-    else:
-        # Get the DACL for the directory
-        dacl = salt.utils.win_dacl.dacl(path)
-
-        # Get current file/folder permissions
-        cur_perms = salt.utils.win_dacl.get_permissions(path)
-
-    # Set 'deny' perms if any
-    if deny_perms is not None:
-        ret['deny'] = {}
-        for user in deny_perms:
-            # Check that user exists:
-            try:
-                user_name = salt.utils.win_dacl.get_name(user)
-            except CommandExecutionError:
-                log.debug('Deny Perms: User "%s" missing from Target System',
-                          user)
-                continue
-
-            # Get applies_to
-            applies_to = None
-            if 'applies_to' not in deny_perms[user]:
-                # Get current "applies to" settings from the file
-                if user_name in cur_perms and 'deny' in cur_perms[user_name]:
-                    for flag in salt.utils.win_dacl.flags().ace_prop['file']:
-                        if salt.utils.win_dacl.flags().ace_prop['file'][flag] == \
-                                cur_perms[user_name]['deny']['applies to']:
-                            at_flag = flag
-                            for flag1 in salt.utils.win_dacl.flags().ace_prop['file']:
-                                if salt.utils.win_dacl.flags().ace_prop['file'][flag1] == at_flag:
-                                    applies_to = flag1
-                if not applies_to:
-                    applies_to = 'this_folder_subfolders_files'
-            else:
-                applies_to = deny_perms[user]['applies_to']
-
-            # Deny permissions
-            if dacl.add_ace(user, 'deny', deny_perms[user]['perms'],
-                            applies_to):
-                ret['deny'][user] = deny_perms[user]
-
-    # Set 'grant' perms if any
-    if grant_perms is not None:
-        ret['grant'] = {}
-        for user in grant_perms:
-            # Check that user exists:
-            try:
-                user_name = salt.utils.win_dacl.get_name(user)
-            except CommandExecutionError:
-                log.debug('Grant Perms: User "%s" missing from Target System',
-                          user)
-                continue
-
-            # Get applies_to
-            applies_to = None
-            if 'applies_to' not in grant_perms[user]:
-                # Get current "applies to" settings from the file
-                if user_name in cur_perms and 'grant' in cur_perms[user_name]:
-                    for flag in salt.utils.win_dacl.flags().ace_prop['file']:
-                        if salt.utils.win_dacl.flags().ace_prop['file'][flag] == \
-                                cur_perms[user_name]['grant']['applies to']:
-                            at_flag = flag
-                            for flag1 in salt.utils.win_dacl.flags().ace_prop['file']:
-                                if salt.utils.win_dacl.flags().ace_prop['file'][flag1] == at_flag:
-                                    applies_to = flag1
-                if not applies_to:
-                    applies_to = 'this_folder_subfolders_files'
-            else:
-                applies_to = grant_perms[user]['applies_to']
-
-            # Grant permissions
-            if dacl.add_ace(user, 'grant', grant_perms[user]['perms'],
-                            applies_to):
-                ret['grant'][user] = grant_perms[user]
-
-    # Order the ACL
-    dacl.order_acl()
-
-    # Save the DACL, setting the inheritance
-    # you have to invert inheritance because dacl.save is looking for
-    # protected. protected True means Inherited False...
-
-    if dacl.save(path, not inheritance):
-        return ret
-
-    return {}
+    return __utils__['dacl.set_perms'](obj_name=path,
+                                       obj_type='file',
+                                       grant_perms=grant_perms,
+                                       deny_perms=deny_perms,
+                                       inheritance=inheritance,
+                                       reset=reset)
