@@ -53,3 +53,33 @@ class RsyncTestCase(TestCase, LoaderModuleMockMixin):
             self.assertRaises(CommandExecutionError, rsync.version)
 
             self.assertEqual(rsync.version(), 'C')
+
+    def test_rsync_excludes_list(self):
+        '''
+        Test for rsync files from src to dst with a list of excludes
+        '''
+        mock = {
+            'config.option': MagicMock(return_value=False),
+            'cmd.run_all': MagicMock()
+        }
+        with patch.dict(rsync.__salt__, mock):
+            rsync.rsync('src', 'dst', exclude=['test/one', 'test/two'])
+        mock['cmd.run_all'].assert_called_once_with(
+            ['rsync', '-avz', '--exclude', 'test/one', '--exclude', 'test/two', 'src', 'dst'],
+            python_shell=False,
+        )
+
+    def test_rsync_excludes_str(self):
+        '''
+        Test for rsync files from src to dst with one exclude
+        '''
+        mock = {
+            'config.option': MagicMock(return_value=False),
+            'cmd.run_all': MagicMock()
+        }
+        with patch.dict(rsync.__salt__, mock):
+            rsync.rsync('src', 'dst', exclude='test/one')
+        mock['cmd.run_all'].assert_called_once_with(
+            ['rsync', '-avz', '--exclude', 'test/one', 'src', 'dst'],
+            python_shell=False,
+        )
